@@ -7,14 +7,13 @@ configuration.
 import logging as _logging
 
 from . import xdg
-from ._config import AbstractConfig, Config
+from ._config import Config
 from ._helpers import NewCommand, comma_list_or_file, new_command_factory
 from ._main import MainType, main_factory
 from ._parser import Parser, filter_cli_args
 
 
 __all__ = [
-    "AbstractConfig",
     "Config",
     "MainType",
     "NewCommand",
@@ -28,6 +27,6 @@ __all__ = [
 
 __author__ = "Bryan M Bugyi"
 __email__ = "bryanbugyi34@gmail.com"
-__version__ = "0.2.0"
+__version__ = "0.2.4"
 
 _logging.getLogger(__name__).addHandler(_logging.NullHandler())
