@@ -10,8 +10,6 @@ from freezegun import freeze_time
 from pytest import fixture
 import structlog
 
-from clack import _dynvars as dyn
-
 
 pytest_plugins = ["logrus.pytest_plugin"]
 
@@ -23,18 +21,6 @@ def frozen_time() -> Iterator[None]:
         yield
 
 
-@fixture(autouse=True)
-def clear_lru_cache() -> None:
-    """Clear function LRU cache before each test.
-
-    Clears cache of functions that have been decorated with
-    @functools.lru_cache before each test.
-    """
-
-    dyn.get_app_name.cache_clear()
-    dyn.get_config_defaults.cache_clear()
-
-
 @fixture(autouse=True)
 def clear_loggers() -> None:
     """Remove handlers from all loggers and unconfigure structlog.
